@@ -1,10 +1,11 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .eval_hooks import DistEvalIterHook, EvalIterHook
-from .metrics import (L1Evaluation, connectivity, gradient_error, mse, niqe,
-                      psnr, reorder_image, sad, ssim)
+from .inceptions import FID, KID, InceptionV3
+from .metrics import (L1Evaluation, connectivity, gradient_error, mae, mse,
+                      niqe, psnr, reorder_image, sad, ssim)
 
 __all__ = [
     'mse', 'sad', 'psnr', 'reorder_image', 'ssim', 'EvalIterHook',
     'DistEvalIterHook', 'L1Evaluation', 'gradient_error', 'connectivity',
-    'niqe'
+    'niqe', 'mae', 'FID', 'KID', 'InceptionV3'
 ]
