@@ -2,11 +2,16 @@
 import copy
 import math
 import numbers
+import os
 import os.path as osp
+import random
 
 import cv2
 import mmcv
 import numpy as np
+import torch
+import torchvision.transforms as transforms
+from PIL import Image
 
 from ..registry import PIPELINES
 
@@ -33,7 +38,7 @@ class Resize:
 
     Args:
         keys (list[str]): The images to be resized.
-        scale (float | Tuple[int]): If scale is Tuple(int), target spatial
+        scale (float | tuple[int]): If scale is tuple[int], target spatial
             size (h, w). Otherwise, target spatial size is scaled by input
             size.
             Note that when it is used, `size_factor` and `max_size` are
@@ -161,7 +166,49 @@ class Resize:
             f'(keys={self.keys}, output_keys={self.output_keys}, '
             f'scale={self.scale}, '
             f'keep_ratio={self.keep_ratio}, size_factor={self.size_factor}, '
-            f'max_size={self.max_size},interpolation={self.interpolation})')
+            f'max_size={self.max_size}, interpolation={self.interpolation})')
+        return repr_str
+
+
+@PIPELINES.register_module()
+class RandomRotation:
+    """Rotate the image by a randomly-chosen angle, measured in degree.
+
+    Args:
+        keys (list[str]): The images to be rotated.
+        degrees (tuple[float] | tuple[int] | float | int): If it is a tuple,
+            it represents a range (min, max). If it is a float or int,
+            the range is constructed as (-degrees, degrees).
+    """
+
+    def __init__(self, keys, degrees):
+        if isinstance(degrees, (int, float)):
+            if degrees < 0.0:
+                raise ValueError('Degrees must be positive if it is a number.')
+            else:
+                degrees = (-degrees, degrees)
+        elif not mmcv.is_tuple_of(degrees, (int, float)):
+            raise TypeError(f'Degrees must be float | int or tuple of float | '
+                            'int, but got '
+                            f'{type(degrees)}.')
+
+        self.keys = keys
+        self.degrees = degrees
+
+    def __call__(self, results):
+        angle = random.uniform(self.degrees[0], self.degrees[1])
+
+        for k in self.keys:
+            results[k] = mmcv.imrotate(results[k], angle)
+            if results[k].ndim == 2:
+                results[k] = np.expand_dims(results[k], axis=2)
+        results['degrees'] = self.degrees
+
+        return results
+
+    def __repr__(self):
+        repr_str = self.__class__.__name__
+        repr_str += (f'(keys={self.keys}, degrees={self.degrees})')
         return repr_str
 
 
@@ -401,7 +448,11 @@ class RandomAffine:
         else:
             shear = 0.0
 
-        flip = (np.random.rand(2) < flip_ratio).astype(np.int) * 2 - 1
+        # Because `flip` is used as a multiplier in line 479 and 480,
+        # so -1 stands for flip and 1 stands for no flip. Thus `flip`
+        # should be an 'inverse' flag as the result of the comparison.
+        # See https://github.com/open-mmlab/mmediting/pull/799 for more detail
+        flip = (np.random.rand(2) > flip_ratio).astype(np.int32) * 2 - 1
 
         return angle, translations, scale, shear, flip
 
@@ -475,7 +526,7 @@ class RandomAffine:
             params = self._get_params(self.degrees, self.translate, self.scale,
                                       self.shear, self.flip_ratio, (h, w))
 
-        center = (w * 0.5 + 0.5, h * 0.5 + 0.5)
+        center = (w * 0.5 - 0.5, h * 0.5 - 0.5)
         M = self._get_inverse_affine_matrix(center, *params)
         M = np.array(M).reshape((2, 3))
 
@@ -566,6 +617,89 @@ class RandomJitter:
         return self.__class__.__name__ + f'hue_range={self.hue_range}'
 
 
+@PIPELINES.register_module()
+class ColorJitter:
+    """An interface for torch color jitter so that it can be invoked in
+    mmediting pipeline.
+
+    Randomly change the brightness, contrast and saturation of an image.
+    Modified keys are the attributes specified in "keys".
+
+    Args:
+        keys (list[str]): The images to be resized.
+        channel_order (str): Order of channel, candidates are 'bgr' and 'rgb'.
+            Default: 'rgb'.
+
+    Notes: ``**kwards`` follows the args list of
+        ``torchvision.transforms.ColorJitter``.
+
+        brightness (float or tuple of float (min, max)): How much to jitter
+            brightness. brightness_factor is chosen uniformly from
+            [max(0, 1 - brightness), 1 + brightness] or the given [min, max].
+            Should be non negative numbers.
+        contrast (float or tuple of float (min, max)): How much to jitter
+            contrast. contrast_factor is chosen uniformly from
+            [max(0, 1 - contrast), 1 + contrast] or the given [min, max].
+            Should be non negative numbers.
+        saturation (float or tuple of float (min, max)): How much to jitter
+            saturation. saturation_factor is chosen uniformly from
+            [max(0, 1 - saturation), 1 + saturation] or the given [min, max].
+            Should be non negative numbers.
+        hue (float or tuple of float (min, max)): How much to jitter hue.
+            hue_factor is chosen uniformly from [-hue, hue] or the given
+            [min, max].
+            Should have 0<= hue <= 0.5 or -0.5 <= min <= max <= 0.5.
+    """
+
+    def __init__(self, keys, channel_order='rgb', **kwargs):
+        assert keys, 'Keys should not be empty.'
+        assert 'to_rgb' not in kwargs, (
+            '`to_rgb` is not support in ColorJitter, '
+            "which is replaced by `channel_order` ('rgb' or 'bgr')")
+
+        self.keys = keys
+        self.channel_order = channel_order
+        self.transform = transforms.ColorJitter(**kwargs)
+
+    def _color_jitter(self, image, this_seed):
+
+        if self.channel_order.lower() == 'bgr':
+            image = image[..., ::-1]
+
+        image = Image.fromarray(image)
+        torch.manual_seed(this_seed)
+        image = self.transform(image)
+        image = np.asarray(image)
+
+        if self.channel_order.lower() == 'bgr':
+            image = image[..., ::-1]
+
+        return image
+
+    def __call__(self, results):
+
+        this_seed = random.randint(0, 2**32)
+
+        for k in self.keys:
+            if isinstance(results[k], list):
+                results[k] = [
+                    self._color_jitter(v, this_seed) for v in results[k]
+                ]
+            else:
+                results[k] = self._color_jitter(results[k], this_seed)
+        return results
+
+    def __repr__(self):
+        repr_str = self.__class__.__name__
+        repr_str += (f'(keys={self.keys}, channel_order={self.channel_order}, '
+                     f'brightness={self.transform.brightness}, '
+                     f'contrast={self.transform.contrast}, '
+                     f'saturation={self.transform.saturation}, '
+                     f'hue={self.transform.hue})')
+
+        return repr_str
+
+
 class BinarizeImage:
     """Binarize image.
 
@@ -758,7 +892,7 @@ class GenerateFrameIndiceswithPadding:
         Returns:
             dict: A dict containing the processed data and information.
         """
-        clip_name, frame_name = results['key'].split('/')
+        clip_name, frame_name = results['key'].split(os.sep)
         current_idx = int(frame_name)
         max_frame_num = results['max_frame_num'] - 1  # start from 0
         num_input_frames = results['num_input_frames']
@@ -808,8 +942,8 @@ class GenerateFrameIndiceswithPadding:
 
 @PIPELINES.register_module()
 class GenerateFrameIndices:
-    """Generate frame index for REDS datasets. It also performs
-    temporal augmention with random interval.
+    """Generate frame index for REDS datasets. It also performs temporal
+    augmention with random interval.
 
     Required keys: lq_path, gt_path, key, num_input_frames
     Added or modified keys:  lq_path, gt_path, interval, reverse
@@ -837,7 +971,7 @@ class GenerateFrameIndices:
             dict: A dict containing the processed data and information.
         """
         clip_name, frame_name = results['key'].split(
-            '/')  # key example: 000/00000000
+            os.sep)  # key example: 000/00000000
         center_frame_idx = int(frame_name)
         num_half_frames = results['num_input_frames'] // 2
 
@@ -997,7 +1131,7 @@ class GenerateSegmentIndices:
 
 @PIPELINES.register_module()
 class MirrorSequence:
-    """Extend short sequences (e.g. Vimeo-90K) by mirroring the sequences
+    """Extend short sequences (e.g. Vimeo-90K) by mirroring the sequences.
 
     Given a sequence with N frames (x1, ..., xN), extend the sequence to
     (x1, ..., xN, xN, ..., x1).
@@ -1038,7 +1172,6 @@ class MirrorSequence:
 class CopyValues:
     """Copy the value of a source key to a destination key.
 
-
     It does the following: results[dst_key] = results[src_key] for
     (src_key, dst_key) in zip(src_keys, dst_keys).
 
@@ -1147,7 +1280,6 @@ class UnsharpMasking:
 
     Added keys are "xxx_unsharp", where "xxx" are the attributes specified
     in "keys".
-
     """
 
     def __init__(self, kernel_size, sigma, weight, threshold, keys):
