@@ -1,4 +1,5 @@
 # Copyright (c) OpenMMLab. All rights reserved.
+from .aot_inpaintor import AOTInpaintor
 from .deepfillv1 import DeepFillv1Inpaintor
 from .gl_inpaintor import GLInpaintor
 from .one_stage import OneStageInpaintor
@@ -7,5 +8,5 @@ from .two_stage import TwoStageInpaintor
 
 __all__ = [
     'OneStageInpaintor', 'GLInpaintor', 'PConvInpaintor', 'TwoStageInpaintor',
-    'DeepFillv1Inpaintor'
+    'DeepFillv1Inpaintor', 'AOTInpaintor'
 ]
