@@ -2,7 +2,7 @@
 from .composition_loss import (CharbonnierCompLoss, L1CompositionLoss,
                                MSECompositionLoss)
 from .feature_loss import LightCNNFeatureLoss
-from .gan_loss import DiscShiftLoss, GANLoss, GradientPenaltyLoss
+from .gan_loss import DiscShiftLoss, GANLoss, GaussianBlur, GradientPenaltyLoss
 from .gradient_loss import GradientLoss
 from .perceptual_loss import (PerceptualLoss, PerceptualVGG,
                               TransferalPerceptualLoss)
@@ -11,8 +11,8 @@ from .utils import mask_reduce_loss, reduce_loss
 
 __all__ = [
     'L1Loss', 'MSELoss', 'CharbonnierLoss', 'L1CompositionLoss',
-    'MSECompositionLoss', 'CharbonnierCompLoss', 'GANLoss',
-    'TransferalPerceptualLoss', 'GradientPenaltyLoss', 'PerceptualLoss',
-    'PerceptualVGG', 'reduce_loss', 'mask_reduce_loss', 'DiscShiftLoss',
-    'MaskedTVLoss', 'GradientLoss', 'LightCNNFeatureLoss'
+    'MSECompositionLoss', 'CharbonnierCompLoss', 'GANLoss', 'GaussianBlur',
+    'GradientPenaltyLoss', 'PerceptualLoss', 'PerceptualVGG', 'reduce_loss',
+    'mask_reduce_loss', 'DiscShiftLoss', 'MaskedTVLoss', 'GradientLoss',
+    'TransferalPerceptualLoss', 'LightCNNFeatureLoss'
 ]
