@@ -6,6 +6,7 @@ from .edvr import EDVR
 from .esrgan import ESRGAN
 from .glean import GLEAN
 from .liif import LIIF
+from .real_basicvsr import RealBasicVSR
 from .real_esrgan import RealESRGAN
 from .srgan import SRGAN
 from .tdan import TDAN
@@ -13,5 +14,5 @@ from .ttsr import TTSR
 
 __all__ = [
     'BasicRestorer', 'SRGAN', 'ESRGAN', 'EDVR', 'LIIF', 'BasicVSR', 'TTSR',
-    'GLEAN', 'TDAN', 'DIC', 'RealESRGAN'
+    'GLEAN', 'TDAN', 'DIC', 'RealESRGAN', 'RealBasicVSR'
 ]
